Changes
=======

0.5.0
------------------

* use uv
* bump min python version to 3.9
* update zeep

0.4.0
------------------

* use poetry
* bump min python version to 3.8
* update zeep

0.3.0
------------------

* Allow to configure cahce params
* update urllib
* handle XMLSyntaxError
* missing anchors

0.2.0
------------------

* Add country pattern map, parsing
* Rename ``is_eu_member`` to ``is_vies_member``